import { Acquire } from './Acquire.js';
export class DomUiManager {
	constructor(resourcePath) {
		this.domElement = null;
		this.loader = new Acquire(resourcePath);
	}

	async load(file) {
		this.domElement = await this.loader.loadDOM(file);
		document.body.appendChild(this.domElement);
	}

	remove() {
		document.body.removeChild(this.domElement);
		this.domElement = null;
	}

	getChildById(id) {
		return document.getElementById(id);
	}

	getChildrenByClassName(className) {
		return document.getElementsByClassName(className) || [];
	}

	toggle(event = null, dataToUpdate = null) {
		if (!this.domElement || !this.domElement.className.split(" ").includes("show")) {
			this.show(dataToUpdate);
		} else {
			this.hide();
		}
	}

	show(dataToUpdate = null) {
		let classes = this.domElement.className.split(" ");
		classes = classes.filter(cn => cn != "show");
		this.domElement.className = classes.join(" ") + " show";

		if(dataToUpdate) {
			for(let key in dataToUpdate){
				let value = dataToUpdate[key];
				this.getChildById(key).value = value;
			}
		}
	}

	hide() {
		let classes = this.domElement.className.split(" ");
		classes = classes.filter(cn => cn != "show");
		this.domElement.className = classes.join(" ");
	}

	muteCanvas() {
		this.domElement.addEventListener("touchstart", e => e.stopImmediatePropagation());
		this.domElement.addEventListener("touchmove", e => e.stopImmediatePropagation());
		this.domElement.addEventListener("touchend", e => e.stopImmediatePropagation());
		this.domElement.addEventListener("mouseup", e => e.stopImmediatePropagation());
		this.domElement.addEventListener("mousemove", e => e.stopImmediatePropagation());
		this.domElement.addEventListener("mousedown", e => e.stopImmediatePropagation());
	}
}