
import { Starfield } from '../canvas-elements/Starfield.js';
import { canvas, fsm, StateKey, webSocket, websocketReconnect } from '../Core.js';
import { Ship } from '../canvas-elements/Ship.js';
import { Acquire } from '../Acquire.js';
export class Room {
	constructor(camera, sector) {
		this.starfield = Starfield.GetInstance();
		this.size = { width: 10000, height: 10000 };
		this.camera = camera;
		this.population = [];
		this.sector = sector;
		this.id = `${sector.x},${sector.y}`;
		this.acquire = new Acquire('');
	}
	init() {
		this.id = `${this.sector.x},${this.sector.y}`;
		this.starfield.init(this.camera);
		this.acquire.apiGet(`./api/room/${this.id}`).then(r => this.addPopulation(r.population));
	}

	update(delta) {
		this.starfield.update(delta);
		this.population.forEach(ship => {
			ship.update(delta);
		});
	}

	draw(context) {
		this.starfield.draw(context);
		this.population.forEach(ship => {
			ship.draw(context);
		});
	}

	addPopulation(population) {
		this.clearPopulation();
		population.forEach(shipData => this.addShip(shipData));
	}

	addShip(shipData) {
		let newShip = new Ship(shipData.position.x, shipData.position.y, "green");
		newShip.init(shipData.position.x, shipData.position.y);
		newShip.id = shipData.id;
		newShip.angle = shipData.angle;
		newShip.velocity.x = shipData.velocity.x;
		newShip.velocity.y = shipData.velocity.y;
		newShip.acceleration.x = shipData.isThrusting ? 0 : shipData.acceleration.x;
		newShip.acceleration.y = shipData.isThrusting ? 0 : shipData.acceleration.y;

		this.population.push(newShip);
	}

	addOtherShip(otherShipData) {
		let newShip = new Ship(otherShipData.position.x, otherShipData.position.y, "green");
		newShip.init(otherShipData.position.x, otherShipData.position.y);
		newShip.id = otherShipData.id;
		newShip.angle = otherShipData.angle;
		newShip.velocity.x = otherShipData.velocity.x;
		newShip.velocity.y = otherShipData.velocity.y;
		newShip.acceleration.x = otherShipData.isThrusting ? 0 : otherShipData.acceleration.x;
		newShip.acceleration.y = otherShipData.isThrusting ? 0 : otherShipData.acceleration.y;
		newShip.isThrusting = otherShipData.isThrusting;
		newShip.color = otherShipData.color;		

		this.population.push(newShip);
	}

	updateOtherShip(otherShipData) {
		let otherShip = this.population.find(os => os.id == otherShipData.id);
		if (otherShip) {
			// otherShip.position.x = otherShipData.position.x;
			// otherShip.position.y = otherShipData.position.y;
			otherShip.angle = otherShipData.angle;
			otherShip.velocity.x = otherShipData.velocity.x;
			otherShip.velocity.y = otherShipData.velocity.y;
			otherShip.acceleration.x = otherShipData.isThrusting ? 0 : otherShipData.acceleration.x;
			otherShip.acceleration.y = otherShipData.isThrusting ? 0 : otherShipData.acceleration.y;
			otherShip.isThrusting = otherShipData.isThrusting;
		}
	}

	removeOtherShip(shipId) {
		let foundIndex = this.population.findIndex(os => os.id == shipId);
		if(foundIndex != -1) {
			this.population.splice(foundIndex, 1);
		}
	}

	clearPopulation() {
		this.population = [];
	}
}