import { canvas } from '../Core.js';
import { keys, KeyCode } from '../KeyboardInput.js';
export class Ship {
	constructor(x, y, color = "green") {
		this.id = "null";
		this.position = { x: x, y: y };
		this.color = color;
		this.velocity = { x: 0.1, y: -0.1 };
		this.acceleration = { x: 0, y: 0 };
		this.target = { x: x, y: y };
		this.futurePoint = { x: x, y: y };
		this.angle = 0;
		this.debug = false;
		this.wrapDelay = 0;
		this.width = 10;
		this.height = 15;
		this.maxThrust = 0.1;
		this.maxVelocity = 5;
		this.isThrusting = false;
	}

	init(x, y) {
		this.position = { x: x, y: y };
		this.velocity = { x: 0.1, y: 0.1 };
		this.acceleration = { x: 0, y: 0 };
		this.target = { x: x, y: y };
		this.futurePoint = { x: 0, y: 0 };
		this.angle = 0;
		this.debug = false;
		this.wrapDelay = 0;
		this.width = 10;
		this.height = 15;
		this.maxThrust = 0.1;
		this.maxVelocity = 5;
		this.isThrusting = false;
	}

	update(delta) {
		if (this.debug && keys[KeyCode.F9]) {
			return;
		}
		this.velocity.x += this.acceleration.x;
		this.velocity.y += this.acceleration.y;

		this.position.x += this.velocity.x * delta;
		this.position.y += this.velocity.y * delta;

		this.velocity.x = Math.sign(this.velocity.x) * Math.min(this.maxVelocity, Math.abs(this.velocity.x));
		this.velocity.y = Math.sign(this.velocity.y) * Math.min(this.maxVelocity, Math.abs(this.velocity.y));
	}

	closeEnough(n1, n2, amount = 0.1) {
		return Math.abs(n1 - n2) <= amount;
	}

	draw(context) {
		let canvasBounds = canvas.getBoundingClientRect();

		context.save();
		context.translate(this.position.x, this.position.y);
		context.rotate(this.angle - (Math.PI / 2));

		context.fillStyle = this.color;
		context.beginPath();
		this.shipShape(context);
		context.fill();

		if (this.isThrusting) {
			context.fillStyle = "cyan";
			context.beginPath();
			this.shipThrustShape(context);
			context.fill();
		}

		context.restore();

		if (this.debug) {
			context.strokeStyle = "yellow";
			context.beginPath();
			context.moveTo(this.position.x, this.position.y);
			context.lineTo(this.target.x, this.target.y);
			context.stroke();

			context.strokeStyle = "red";
			context.beginPath();
			context.moveTo(this.position.x, this.position.y);
			context.lineTo(canvasBounds.width, this.position.y);
			context.stroke();

			context.strokeStyle = "red";
			context.beginPath();
			context.moveTo(this.position.x, this.position.y);
			context.lineTo(0, this.position.y);
			context.stroke();

			context.strokeStyle = "cyan";
			context.beginPath();
			context.moveTo(this.position.x, this.position.y);
			context.lineTo(this.position.x, canvasBounds.height);
			context.stroke();

			context.strokeStyle = "cyan";
			context.beginPath();
			context.moveTo(this.position.x, this.position.y);
			context.lineTo(this.position.x, 0);
			context.stroke();

			context.fillStyle = "yellow";
			context.beginPath();
			context.moveTo(this.position.x, this.position.y);
			context.arc(this.futurePoint.x, this.futurePoint.y, 2, 0, 2 * Math.PI);
			context.fill();
		}
	}

	shipShape(context) {
		context.moveTo(this.width / 2, -this.height / 2);
		context.lineTo(0, this.height / 2);
		context.lineTo(-this.width / 2, -this.height / 2);
		context.lineTo(this.width / 2, -this.height / 2);
	}

	shipThrustShape(context) {
		context.moveTo(-this.width / 4, -this.height / 2);
		context.lineTo(this.width / 4, -this.height / 2);
		context.lineTo(0, -1.2 * this.height);
		context.lineTo(-this.width / 4, -this.height / 2);
	}

	setTarget(x, y) {
		this.target.x = x;
		this.target.y = y;
	}

	thrustDirection(angle) {
		this.isThrusting = true;
		this.acceleration.x = this.maxThrust * Math.cos(angle);
		this.acceleration.y = this.maxThrust * Math.sin(angle);
		this.setAngle(angle);
	}

	isAccelerating() {
		return this.isThrusting;
	}

	stopThrust() {
		this.isThrusting = false;
		this.acceleration.x = 0;
		this.acceleration.y = 0;
	}

	setAngle(angle) {
		this.angle = angle;
	}
}