export class Starfield {
	static instance;

	static GetInstance() {
		if (!Starfield.instance) {
			Starfield.instance = new Starfield();
		}
		return Starfield.instance;
	}

	constructor() {
		this.size = { width: 10000, height: 10000 };
		this.fields = [];
		this.camera = {x: 5000, y: 5000};
	}

	createField(amount, depth) {
		let stars = [];
		for (let i = 0; i < amount; i++) {
			stars.push({ x: this.size.width * Math.random(), y: this.size.height * Math.random(), depth: depth });
		}
		let field = { x: 0, y: 0, depth: depth, stars: stars, offsetX: 0, offsetY: 0 };
		return field;
	}

	drawStars(context, stars) {
		context.fillStyle = "white";
		for (let i = 0; i < stars.length; i++) {
			let star = stars[i];
			context.beginPath();
			context.arc(star.x, star.y, star.depth, 0, 2 * Math.PI);
			context.fill();
		}
	}

	updateField(field) {
		field.x += 0.1 * Math.pow(field.depth, 2);
		field.y += 0.1 * Math.pow(field.depth, 2);
		if (field.x > this.size.width) {
			field.x -= this.size.width;
		}

		if (field.y > this.size.height) {
			field.y -= this.size.height;
		}
	}

	updateStars(stars) {
		// let cameraVsRoom = {x: this.camera.x - (this.size.width  /2), y: this.camera.y - (this.size.height / 2) };
		// for (let i = 0; i < stars.length; i++) {
		// 	let star = stars[i];
		// 	let offsetX = 1 / star.depth * cameraVsRoom.x;
		// 	let offsetY = 1 / star.depth * cameraVsRoom.y;
		// 	star.x = offsetX;
		// 	star.y = offsetY;
		// 	if (star.x > this.size.width) {
		// 		star.x -= this.size.width;
		// 	}

		// 	if (star.y > this.size.height) {
		// 		star.y -= this.size.height;
		// 	}
		// }
	}

	init(camera) {
		this.camera = camera;
		if (this.fields.length == 0) {
			this.fields.push(this.createField(3000, 1));
			this.fields.push(this.createField(1000, 2));
			this.fields.push(this.createField(500, 3));
		}
	}
	update(delta) {
		let cameraVsRoom = {x: this.camera.x - (this.size.width / 2), y: this.camera.y - (this.size.height / 2) };
		for (let i = 0; i < this.fields.length; i++) {
			let field = this.fields[i];
			let offsetX = (1 / (1 + field.depth)) * cameraVsRoom.x;
			let offsetY = (1 / (1 + field.depth)) * cameraVsRoom.y;
			field.offsetX = parseFloat(offsetX.toPrecision(8));
			field.offsetY = parseFloat(offsetY.toPrecision(8));
			this.updateStars(field.stars);
		}
	}
	draw(context) {		
		for (let i = 0; i < this.fields.length; i++) {
			let field = this.fields[i];
			context.save();
			context.translate(field.offsetX, field.offsetY);
			this.drawStars(context, field.stars);
			context.restore();
		}
	}
}