import { canvas, fsm, StateKey, websocketReconnect } from '../Core.js';
import { Logger } from '../Logger.js';

export class LoadingState {
	constructor() {
		this.timeStart = 0;
		this.barPercentage = 0;
		this.cheatDuration = 300;
	}
	async start() {
		this.timeStart = new Date().getTime();
		await new Promise(resolve => setTimeout(resolve, this.cheatDuration));
		canvas.style.opacity = 1;
		fsm.transitionTo(StateKey.MainMenu);
	}
	async end() {
		canvas.style.opacity = 0;
		await new Promise(resolve => setTimeout(resolve, 1000));
	}
	update(delta) {
		let currentTime = new Date().getTime();
		this.barPercentage = Math.min(1, (currentTime - this.timeStart) / this.cheatDuration);
	}
	draw(context) {
		let canvasBounds = canvas.getBoundingClientRect();
		context.fillStyle = "black";
		context.beginPath();
		context.rect(0, 0, canvasBounds.width, canvasBounds.height);
		context.fill();


		context.fillStyle = "white";
		context.beginPath();
		context.rect(0, canvasBounds.height - 11, this.barPercentage * canvasBounds.width, 10);
		context.fill();

		context.font = "3em 'Syne Mono', serif";
		context.textAlign = "center";
		context.fillText("Loading...", canvasBounds.width / 2, canvasBounds.height / 2);
	}

	websocketConnect(websocket, event) {
		Logger.info("load sent:", "echo testing!");
		websocket.send("echo testing!");
	}

	websocketMessage(websocket, event) {
		Logger.info("load received:", event.data);
	}

	websocketClose(websocket, event) {
		Logger.info("load disconnected:", event);
		setTimeout(websocketReconnect, 5000);
	}
}
